 // Глобальная переменная для хранения экземпляра SDK
window.ysdk = null; 
let ysdkPlayer = null; // Будем хранить экземпляр игрока

function fastunlockGame() {
	
    initGame();
	changeHiddenCellTheme();
	const gameContainer = document.querySelector('.game-container');
    const loadingOverlay = document.getElementById('loadingOverlay');
    
    if (gameContainer) gameContainer.style.display = 'flex';
    if (loadingOverlay) {
    loadingOverlay.style.opacity = '0';
    loadingOverlay.remove();   
}

}

function unlockGame() {
	
grasdk();

}


// Добавляем таймер автосохранения
let autoSaveTimer = null;

function initYandexSDK() {
    if (typeof YaGames === 'undefined') {
        console.warn("YaGames не обнаружен. Локальный режим.");
        loadLocalData();
        unlockGame();
        return;
    }

    YaGames.init()
        .then(async (sdk) => {
            window.ysdk = sdk;

            try {
                ysdkPlayer = await window.ysdk.getPlayer();
                console.log("Игрок получен", ysdkPlayer);
                checkAdsFlag();
				detectLanguage();
                await loadCloudData();
                startAutoSaveTimer();
                unlockGame();
            } catch (error) {
                console.error("Ошибка получения игрока:", error);
				checkAdsFlag();
				detectLanguage();
                loadLocalData();
                unlockGame();
            }
        })
        .catch((error) => {
            console.error("Ошибка SDK:", error);
            loadLocalData();
            unlockGame();
        });
}

//Геймреди
function grasdk() {
	
window.ysdk.features?.LoadingAPI?.ready();

}


// Функция запуска таймера автосохранения
function startAutoSaveTimer() {
    // Останавливаем предыдущий таймер, если был
    if (autoSaveTimer) {
        clearInterval(autoSaveTimer);
    }
    
    // Запускаем новый таймер
    autoSaveTimer = setInterval(() => {
        console.log('Автосохранение данных...');
        saveGameScoreToYandex();
    }, 15000); // 15 секунд = 15000 миллисекунд
    
    // Сохраняем сразу при запуске
    saveGameScoreToYandex();
}

// Останавливаем таймер при закрытии страницы
window.addEventListener('beforeunload', () => {
    if (autoSaveTimer) {
        clearInterval(autoSaveTimer);
    }
    // Сохраняем перед закрытием
    saveGameScoreToYandex();
});

// Функция загрузки данных из облака
async function loadCloudData() {
    if (!ysdkPlayer) {
        console.error("Игрок не инициализирован");
        return;
    }

    try {
        // Получаем данные из облака
        const cloudData = await ysdkPlayer.getData();
        console.log('Данные из облака:', cloudData);

        if (cloudData && cloudData.gameScore !== undefined) {
            // Обновляем gameState и локальное хранилище
            gameState.score = cloudData.gameScore;
            localStorage.setItem('pairsGameScore', gameState.score.toString());
            console.log('Данные синхронизированы из облака:', gameState.score);
        } else {
            console.log('Облачные данные не найдены, используем локальные');
            loadLocalData();
        }
    } catch (error) {
        console.error('Ошибка загрузки из облака:', error);
        loadLocalData(); // Если не удалось, загружаем локальные данные
    }
}

// Функция загрузки локальных данных
function loadLocalData() {
    const localScore = parseInt(localStorage.getItem('pairsGameScore')) || 0;
    gameState.score = localScore;
    console.log('Данные загружены из локального хранилища:', gameState.score);
}

// Функция сохранения данных (как у вас было, с небольшими улучшениями)
async function saveGameScoreToYandex() {
    if (!ysdkPlayer) {
        console.error("Игрок не инициализирован");
        return;
    }

    const score = gameState.score || parseInt(localStorage.getItem('pairsGameScore')) || 0;
    
    try {
        // Пытаемся сохранить в облако
        await ysdkPlayer.setData({ gameScore: score }, true);
        console.log('Счёт сохранён в облако:', score);
    } catch (error) {
        console.error('Ошибка облачного сохранения:', error);
        
        try {
            // Пробуем сохранить локально
            await ysdkPlayer.setData({ gameScore: score }, false);
            console.log('Счёт сохранён локально (SDK):', score);
        } catch (localError) {
            console.error('Ошибка локального сохранения (SDK):', localError);
            // Сохраняем только в localStorage
            localStorage.setItem('pairsGameScore', score.toString());
            console.log('Счёт сохранён в localStorage:', score);
        }
    }
}


	
function showAds() {
    // Проверяем наличие SDK и рекламного модуля
    if (!window.ysdk?.adv) {
        console.log('Реклама недоступна (нет SDK)');
        return;
    }

    // Просто показываем рекламу с базовыми колбэками
    window.ysdk.adv.showFullscreenAdv({
        callbacks: {
            onOpen: () => console.log('Реклама открыта'),
            onClose: (wasShown) => {
                if (wasShown) {
                    console.log('Игрок просмотрел рекламу');
                    // Тут можно дать награду
                } else {
                    console.log('Реклама не была показана');
                }
            },
            onError: (e) => console.log('Ошибка рекламы:', e)
        }
    }).catch(e => console.log('Ошибка при показе:', e));
}

function checkAdsFlag() {
    window.ysdk.getFlags()
        .then(flags => {
            if (flags.ads == 1) { 
                showAds(); 
            }
        })
        .catch(error => {
            console.error("Ошибка при получении флагов:", error);
        });
}



// Словарь переводов
const translations = {
    en: {
        scoreLabel: "Score",
        newGame: "New Game",
        congratulations: "Congratulations!",
        youScored: "You scored points:",
        playAgain: "Play Again"
    },
    ru: {
        scoreLabel: "Очки",
        newGame: "Новая игра",
        congratulations: "Поздравляем!",
        youScored: "Вы набрали очков:",
        playAgain: "Играть снова"
    }
};

// Текущий язык (по умолчанию русский)
let currentLanguage = 'ru';

// Определение языка через Yandex SDK
async function detectLanguage() {
    try {
        if (window.ysdk) {
           
            const langCode = window.ysdk.environment.i18n.lang;
            
            // Определяем язык (поддерживаем только ru/en)
            currentLanguage = langCode.startsWith('ru') ? 'ru' : 'en';
        }
    } catch (error) {
        console.error('Language detection error:', error);
    } finally {
        applyTranslations();
    }
}

// Применение переводов
function applyTranslations() {
    const langStrings = translations[currentLanguage] || translations.ru;
    
    // Обновляем элементы интерфейса
    const updateElement = (selector, text, isHTML = false) => {
        const element = document.querySelector(selector);
        if (element) {
            isHTML ? element.innerHTML = text : element.textContent = text;
        }
    };
    
    updateElement('.score-label', langStrings.scoreLabel);
    updateElement('#restart', langStrings.newGame);
    updateElement('#winlogo', langStrings.congratulations);
    updateElement('#winbe', langStrings.youScored);
    updateElement('#playAgain', langStrings.playAgain);
}

// Запускаем инициализацию при загрузке страницы
document.addEventListener('DOMContentLoaded', initYandexSDK);

    // Звуковые эффекты
    const soundEffects = {
        click: new Audio('tap.mp3'),
		won: new Audio('won.mp3'),
        match: new Audio('coin.mp3')
    };
	soundEffects.click.volume = 0.01;
    soundEffects.match.volume = 0.2;
	soundEffects.won.volume = 0.2;
	
	// Проверяем, является ли устройство Apple
const isAppleDevice = () => /iPhone|iPad|iPod|Macintosh/i.test(navigator.userAgent);

// Если устройство Apple, блокируем воспроизведение звуков
if (isAppleDevice()) {
    Object.values(soundEffects).forEach(audio => {
        // Заменяем метод play на пустую функцию
        audio.play = () => Promise.resolve();
    });
}
    
    // Состояние игры
    const gameState = {
        score: localStorage.getItem('pairsGameScore') ? parseInt(localStorage.getItem('pairsGameScore')) : 0,
        grid: [],
        selectedCells: [],
        matchedPairs: 0,
        totalPairs: 18,
        isProcessing: false,
        hintPair: []
    };
    
    // Инициализация игры
    function initGame() {
        gameState.selectedCells = [];
        gameState.matchedPairs = 0;
        gameState.isProcessing = false;
        gameState.hintPair = [];
        updateScore();
        createGrid();
        winMessage.style.display = 'none';
        
        // Показываем подсказку в начале игры
        showInitialHint(); 
    }
    
    // Показ начальной подсказки (одна случайная пара)
    function showInitialHint() {
        // Находим все непарные клетки
        const unpairedCells = gameState.grid
            .map((cell, index) => ({...cell, index}))
            .filter(cell => !cell.isMatched && cell.value !== 0);
        
        if (unpairedCells.length < 2) return;
        
        // Находим все возможные пары
        const valueCounts = {};
        unpairedCells.forEach(cell => {
            valueCounts[cell.value] = (valueCounts[cell.value] || 0) + 1;
        });
        
        const availablePairs = Object.keys(valueCounts)
            .filter(value => valueCounts[value] >= 2)
            .map(Number);
        
        if (availablePairs.length === 0) return;
        
        // Выбираем случайную пару
        const hintValue = availablePairs[Math.floor(Math.random() * availablePairs.length)];
        const hintCells = unpairedCells
            .filter(cell => cell.value === hintValue)
            .slice(0, 2);
        
        // Показываем подсказку
        hintCells.forEach(cell => {
            gameState.grid[cell.index].element.classList.remove('hidden');
        });
        
        // Запоминаем пару для подсказки
        gameState.hintPair = hintCells.map(cell => cell.index);
        
        // Скрываем подсказку через 10 секунд
        setTimeout(() => {
            gameState.hintPair.forEach(index => {
                if (!gameState.grid[index].isMatched && !gameState.grid[index].isRevealed) {
                    gameState.grid[index].element.classList.add('hidden');
                }
            });
            gameState.hintPair = [];
        }, 10000);
    }
    
    function createGrid() {
        gridElement.innerHTML = '';
        gameState.grid = [];
        
        let numbers = [];
        for (let i = 1; i <= gameState.totalPairs; i++) {
            numbers.push(i, i);
        }
        
        numbers = shuffleArray(numbers);
        
        for (let i = 0; i < 36; i++) {
            const cell = document.createElement('div');
            cell.className = 'cell hidden';
            cell.dataset.index = i;
            
            const cellContent = document.createElement('div');
            cellContent.className = 'cell-content';
            cellContent.textContent = numbers[i];
            
            cell.appendChild(cellContent);
            cell.addEventListener('click', () => handleCellClick(i));
            
            gridElement.appendChild(cell);
            gameState.grid.push({
                element: cell,
                content: cellContent,
                value: numbers[i],
                isMatched: false,
                isRevealed: false
            });
        }
    }
    
    // Элементы DOM
    const gridElement = document.getElementById('grid');
    const scoreElement = document.getElementById('score');
    const restartButton = document.getElementById('restart');
    const winMessage = document.getElementById('winMessage');
    const finalScoreElement = document.getElementById('finalScore');
    const playAgainButton = document.getElementById('playAgain');
    
    // Обработка клика по клетке
    function handleCellClick(index) {
        if (gameState.isProcessing || index < 0 || index >= gameState.grid.length) return;
        
        const cell = gameState.grid[index];
        if (cell.isRevealed || cell.isMatched) return;
        
        // Воспроизводим звук клика
        soundEffects.click.currentTime = 0;
        soundEffects.click.play().catch(e => console.log("Audio play error:", e));
        
        revealCell(index);
        gameState.selectedCells.push(index);
        
        if (gameState.selectedCells.length === 2) {
            checkForMatch();
        }
    }
    
   // Открытие клетки (удаляем hidden + сбрасываем градиент)
function revealCell(index) {
    const cell = gameState.grid[index];
    cell.isRevealed = true;
    cell.element.classList.remove('hidden');
    cell.element.style.background = ''; // Сброс стиля
}

// Скрытие клетки (добавляем hidden + применяем текущую тему)
function hideCell(index) {
    const cell = gameState.grid[index];
    cell.isRevealed = false;
    cell.element.classList.add('hidden');
    // Если нужно, можно применить градиент тут:
    // cell.element.style.background = currentTheme;
}
    
    // Проверка на совпадение
    function checkForMatch() {
        gameState.isProcessing = true;
        
        const [firstIndex, secondIndex] = gameState.selectedCells;
        const firstCell = gameState.grid[firstIndex];
        const secondCell = gameState.grid[secondIndex];
        
        if (firstCell.value === secondCell.value) {
            // Воспроизводим звук совпадения
            soundEffects.match.currentTime = 0;
            soundEffects.match.play().catch(e => console.log("Audio play error:", e));
            
            firstCell.isMatched = true;
            secondCell.isMatched = true;
            firstCell.element.classList.add('matched');
            secondCell.element.classList.add('matched');
            
            gameState.score += 10; // Добавляем очки за найденную пару
            updateScore();
            saveScore(); // Сохраняем общий счет
            
            gameState.matchedPairs++;
            gameState.selectedCells = [];
            gameState.isProcessing = false;
            
            if (gameState.matchedPairs === gameState.totalPairs) {
                setTimeout(showWinMessage, 500);
            }
        } else {
            setTimeout(() => {
                hideCell(firstIndex);
                hideCell(secondIndex);
                gameState.selectedCells = [];
                gameState.isProcessing = false;
            }, 1000);
        }
    }
    
    // Сохранение счета и отправка в лидерборд
function saveScore() {
    const score = gameState.score.toString();
    localStorage.setItem('pairsGameScore', score);
    
    // Отправка счета в лидерборд Yandex Games
    if (window.ysdk) {
        window.ysdk.getLeaderboards()
            .then(leaderboards => {
                return leaderboards.setLeaderboardScore('alltop', parseInt(score));
            })
            .then(() => {
                console.log('Score sent to leaderboard successfully');
            })
            .catch(error => {
                console.error('Leaderboard error:', error);
            });
    }
}
    
    // Показ сообщения о победе
     function showWinMessage() {
	    soundEffects.won.currentTime = 0;
        soundEffects.won.play().catch(e => console.log("Audio play error:", e));
        finalScoreElement.textContent = gameState.score;
        winMessage.style.display = 'block';
        createConfetti();
    }
    
    // Создание конфетти
    function createConfetti() {
        const colors = ['#ff0000', '#00ff00', '#0000ff', '#ffff00', '#ff00ff', '#00ffff'];
        const container = document.querySelector('.game-container');
        
        for (let i = 0; i < 100; i++) {
            const confetti = document.createElement('div');
            confetti.className = 'confetti';
            confetti.style.backgroundColor = colors[Math.floor(Math.random() * colors.length)];
            confetti.style.left = Math.random() * 100 + '%';
            confetti.style.top = -10 + 'px';
            confetti.style.width = Math.random() * 10 + 5 + 'px';
            confetti.style.height = confetti.style.width;
            
            container.appendChild(confetti);
            
            const animationDuration = Math.random() * 3 + 2;
            confetti.style.animation = `fall ${animationDuration}s linear forwards`;
            
            setTimeout(() => {
                confetti.remove();
            }, animationDuration * 1000);
        }
        
        const style = document.createElement('style');
        style.innerHTML = `
            @keyframes fall {
                to {
                    transform: translateY(calc(100vh + 10px)) rotate(720deg);
                    opacity: 0;
                }
            }
        `;
        document.head.appendChild(style);
    }
    
    // Обновление счета на экране
    function updateScore() {
        scoreElement.textContent = gameState.score;
    }
    
    // Перемешивание массива
    function shuffleArray(array) {
        const newArray = [...array];
        for (let i = newArray.length - 1; i > 0; i--) {
            const j = Math.floor(Math.random() * (i + 1));
            [newArray[i], newArray[j]] = [newArray[j], newArray[i]];
        }
        return newArray;
    }
    
    // Обработчики кнопок
restartButton.addEventListener('click', () => {
    initGame();
changeHiddenCellTheme();	
	showAds(); 
	
 
});

playAgainButton.addEventListener('click', () => {
    initGame();
changeHiddenCellTheme();	
    showAds();
	
});
    

function changeHiddenCellTheme() {
const gradientThemes = [

    'linear-gradient(135deg, #ffb347 0%, #ffcc33 100%)', // Апельсиновый
    'linear-gradient(135deg, #43e97b 0%, #38f9d7 100%)',  // Мятно-бирюзовый
    'linear-gradient(135deg, #a18cd1 0%, #fbc2eb 100%)',  // Сиренево-розовый

    // Натуральные
    'linear-gradient(135deg, #48c6ef 0%, #6f86d6 100%)',  // Морская волна
   


    // Сочные, но мягкие
    'linear-gradient(135deg, #ffc3a0 0%, #ffafbd 100%)',  // Персиковый
    'linear-gradient(135deg, #c471f5 0%, #fa71cd 100%)',  // Пурпурный
    'linear-gradient(135deg, #f6d365 0%, #fda085 100%)'   // Золотисто-оранжевый
];

    currentTheme = gradientThemes[Math.floor(Math.random() * gradientThemes.length)];
    
    // Применяем только к .cell.hidden
    document.querySelectorAll('.cell.hidden').forEach(cell => {
        cell.style.background = currentTheme;
    });
}

function startAdInterval() {
  // Запускаем сразу при старте
  //showAds();
  
  // Затем каждые 65 секунд (1 минута и 5 секунд)
  setInterval(showAds, 65 * 1000);
}


fastunlockGame();